@@ -1,7 +1,8 @@
-# $Id: addModel.R 72 2010-09-11 17:06:14Z Lars $
+# $Id: addModel.R 76 2010-10-12 13:45:37Z lo $
 
 # Additive model, corresponds to eqs. 4.34-4.38 in Cooper et al., 2007 
-add.dea <- function(X, Y, RTS="vrs", TRANSPOSE=FALSE,...)  {
+dea.add <- function(X, Y, RTS="vrs", TRANSPOSE=FALSE,
+        XREF=NULL, YREF=NULL, FRONT.IDX=NULL, LP=FALSE)  {
 	if ( TRANSPOSE ) {
 		K <- dim(X)[2]
 	} else {
@@ -10,7 +11,7 @@ add.dea <- function(X, Y, RTS="vrs", TRANSPOSE=FALSE,...)  {
 	e <- list(eff=rep(1,K), objval=NULL, RTS=RTS, 
         ORIENTATION="in", TRANSPOSE=TRANSPOSE)
    class(e) <- "Farrell"
-	sl <- slack(X,Y,e,...)
+	sl <- slack(X,Y,e, XREF=XREF, YREF=YREF, FRONT.IDX=FRONT.IDX, LP=LP)
 
 	# Make slack the sum of slacks, not a logical variable 
 	# wether there is slack or not
@@ -20,4 +21,5 @@ add.dea <- function(X, Y, RTS="vrs", TRANSPOSE=FALSE,...)  {
 #      sl$sum2 <- rowSums(sl$sx) + rowSums(sl$sy)
 
 	return(sl)
-}  # aff.dea
+}  # dea.aff
+
